//****************************************************************
//  P0P1Touch.h  /  2.2.14  /  rw  /  bzu
//  Enthlt die Funktionen zur Darstellung von P0 und P1 des
//  Hauptprogramms auf dem Grafikdisplay.
//  Touch-Eingabe parallel zur Pin-Eingabe GPIOC0..7
//  Touch-Ausgabe parallel zur Pin-Ausgabe LEDs an GPIOE8..15
//****************************************************************
#ifndef __P0P1Touch_h
#define __P0P1Touch_h

// Touch enthlt den Eingabezustand der Bits vom Display um mit der
// physischen Porteingabe AND-verknpft zu werden
extern unsigned char TouchP0[8], TouchAllP0;// = {1,1,1,1,1,1,1,1};
// ----------- Bit Banding fr read/write auf gleichen Bezeichner ------
// Define base address of peripheral bit-band
// #define PERIPH_BASE 0x40000000
// Define base address of peripheral alias band
// #define PERIPH_BB_BASE 0x42000000
// Convert PERI address to alias region
#define BITBAND_PERI(a,b) ((PERIPH_BB_BASE + (((uint32_t)a)-PERIPH_BASE)*32 + (b*4)))
/*
// In dieser Variante nicht mit dem Touchdisplay verknpft
#define P0_0 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOC->IDR,0)))) 
#define P0_1 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOC->IDR,1)))) 
#define P0_2 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOC->IDR,2)))) 
#define P0_3 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOC->IDR,3)))) 
#define P0_4 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOC->IDR,4)))) 
#define P0_5 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOC->IDR,5)))) 
#define P0_6 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOC->IDR,6)))) 
#define P0_7 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOC->IDR,7)))) 
*/
// In dieser Variante  mit dem Touchdisplay verknpft
// BZU-Kompatibiltaet zu 1Bit Manipulation: P0_0 .. P0_7 Input von GPIOC0..7
#define P0_0 (((unsigned char)TouchP0[0])&(*((volatile unsigned char *)(BITBAND_PERI(&GPIOC->IDR,0))))) 
#define P0_1 (((unsigned char)TouchP0[1])&(*((volatile unsigned char *)(BITBAND_PERI(&GPIOC->IDR,1)))))
#define P0_2 (((unsigned char)TouchP0[2])&(*((volatile unsigned char *)(BITBAND_PERI(&GPIOC->IDR,2))))) 
#define P0_3 (((unsigned char)TouchP0[3])&(*((volatile unsigned char *)(BITBAND_PERI(&GPIOC->IDR,3))))) 
#define P0_4 (((unsigned char)TouchP0[4])&(*((volatile unsigned char *)(BITBAND_PERI(&GPIOC->IDR,4))))) 
#define P0_5 (((unsigned char)TouchP0[5])&(*((volatile unsigned char *)(BITBAND_PERI(&GPIOC->IDR,5))))) 
#define P0_6 (((unsigned char)TouchP0[6])&(*((volatile unsigned char *)(BITBAND_PERI(&GPIOC->IDR,6))))) 
#define P0_7 (((unsigned char)TouchP0[7])&(*((volatile unsigned char *)(BITBAND_PERI(&GPIOC->IDR,7)))))

// BZU-Kompatibiltaet zu 1Bit Manipulation: P1_0 .. P1_7 Output nach GPIOE8..15
#define P1_0 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOE->ODR,8)))) 
#define P1_1 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOE->ODR,9)))) 
#define P1_2 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOE->ODR,10)))) 
#define P1_3 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOE->ODR,11)))) 
#define P1_4 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOE->ODR,12)))) 
#define P1_5 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOE->ODR,13)))) 
#define P1_6 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOE->ODR,14)))) 
#define P1_7 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOE->ODR,15)))) 

// OnBoard Controlstick 5Bit InByte PD_11 .. PD_15 von GPIOD high
#define PD_11 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOD->IDR,11)))) 
#define PD_12 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOD->IDR,12)))) 
#define PD_13 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOD->IDR,13)))) 
#define PD_14 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOD->IDR,14))))
#define PD_15 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOD->IDR,15))))

// OnBoard Controlstick 5Bit InByte PD_11 .. PD_15 von GPIOD high
#define PA_0  (*((volatile unsigned char *)(BITBAND_PERI(&GPIOA->IDR,0)))) 
#define PC_13 (*((volatile unsigned char *)(BITBAND_PERI(&GPIOC->IDR,13)))) 

// BZU-Kompatibiltaet zu 8Bit InByte P0 von GPIOC low und OutByte P1 nach GPIOE high
#define P0  (((unsigned char)TouchAllP0)&(*((volatile unsigned char *)(&(GPIOC->IDR))))) // In Bit0..7 als Byte
#define P1  (*((volatile unsigned char *)(&(GPIOE->ODR))+1)) // Out Bit8..15 als Byte
#define PD_High (*((volatile unsigned char *)(&(GPIOD->IDR))+1)) // In Bit8..15 als Byte fr CtrlStick

#include<stdint.h>


typedef struct
{
	uint16_t PosX, PosY;
	uint16_t Width, Height;
	char caption[12];
	long ONColor, OFFColor;
	uint8_t status;
} TPit;

/* Private functions ---------------------------------------------------------*/
void InitP0P1(void);
void InitP0P1Touch(uint16_t StartType);
void TSCTouchHandle(void);
void TSCPIORefresh(void);
void delay_ms(uint32_t nTime);	 		//Delay mS
void ET_STM32_RCC_Configuration(void);		//Config Clock
void TimingDelay_Decrement(void);
void Delay(uint32_t nTime);
void plot_tab_Ver1(uint16_t x, uint16_t y, uint16_t w, uint16_t h, unsigned long color);
void drawPit(TPit Pit, uint8_t Stat);

	
//-----------------------------------------------------------------------------------
#ifdef  USE_FULL_ASSERT
/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  /* Infinite loop */
  while (1)
  {
  }
}
#endif

#endif /* __Touch8Bit_h */

/******************* (C) COPYRIGHT 2009 STMicroelectronics *****END OF FILE****/
